@@ -110,12 +110,15 @@ def update_state():
             filler, schema_name, hostname, remote_host, remote_port, local_address, local_port, forward_type = values
 
             schema = models.Schema.find_by_name(schema_name)
-            # schema.active = True
-            session = schema.get_session(forward_type, hostname, int(remote_port))
-            session.connected = True
-            # session.local_address = local_address
-            session.local_port = local_port
-            settings.ports_active.append(local_port)
+            if schema:
+                # schema.active = True
+                session = schema.get_session(forward_type, hostname, int(remote_port))
+                session.connected = True
+                # session.local_address = local_address
+                session.local_port = local_port
+                settings.ports_active.append(local_port)
+            else:
+                print("TMUX session active but missing session definition.")
 
 
 def filter_session(session: models.Session, schema_name: str = None, host: str = None, port: str = None):
